spawn_shell_commands_in_terminal

Function spawn_shell_commands_in_terminal 

pub fn spawn_shell_commands_in_terminal(cmds: &[String])
What: Spawn a terminal to run a &&-joined series of shell commands with a hold tail.

Input:

  • cmds: Ordered list of shell snippets to execute.

Output:

  • Starts the preferred terminal (or bash) running the composed command sequence.

Details:

  • Defers to spawn_shell_commands_in_terminal_with_hold to add the default hold tail.
  • During tests, this is a no-op to avoid opening real terminal windows, unless PACSEA_TEST_OUT is set.